# yum-rabbitmq Cookbook
[![Build Status](https://travis-ci.org/chasebolt/chef-yum-rabbitmq.svg?branch=master)](http://travis-ci.org/chasebolt/chef-yum-rabbitmq) [![Cookbook Version](https://img.shields.io/cookbook/v/yum-rabbitmq.svg)](https://supermarket.chef.io/cookbooks/yum-rabbitmq)

The yum-rabbitmq cookbook takes over management of the default repositoryids used with the official rabbitmq repositories. It allows attribute manipulation of the `rabbitmq` yum channel.

## Requirements
- Chef 11+
- yum version 3.2.0 or higher

### Platforms
- Fedora and RHEL based distributions (RHEL, CentOS, and Scientific Linux) are supported

## Attributes
The following attributes are set by default

```ruby
default['yum']['rabbitmq']['description'] = 'RabbitMQ Repository'
default['yum']['rabbitmq']['baseurl'] = 'https://dl.bintray.com/rabbitmq/rabbitmq-server-rpm'
default['yum']['rabbitmq']['gpgcheck'] = false
default['yum']['rabbitmq']['enabled'] = true
default['yum']['rabbitmq']['managed'] = true

default['yum']['rabbitmq-erlang']['description'] = 'RabbitMQ Erlang Repository'
default['yum']['rabbitmq-erlang']['baseurl'] = 'https://dl.bintray.com/rabbitmq/erlang'
default['yum']['rabbitmq-erlang']['gpgcheck'] = false
default['yum']['rabbitmq-erlang']['enabled'] = true
default['yum']['rabbitmq-erlang']['managed'] = true
default['yum']['rabbitmq-erlang']['includepkgs'] = "*.el#{platform_version.to_i}.*"
```

## Recipes
- default - Walks through node attributes and feeds a yum_resource
- parameters. The following is an example a resource generated by the
- recipe during compilation.

```ruby
  yum_repository 'rabbitmq' do
    baseurl 'https://dl.bintray.com/rabbitmq/rabbitmq-server-rpm'
    description 'RabbitMQ Repository'
    enabled true
    gpgcheck false
  end

  yum_repository 'rabbitmq-erlang' do
    baseurl 'https://dl.bintray.com/rabbitmq/erlang'
    description 'RabbitMQ Erlang Repository'
    enabled true
    gpgcheck false
    includepkgs '*.el7.*'
  end
```

## Usage Example
To disable the rabbitmq repository through a Role or Environment definition

```ruby
default_attributes(
  :yum => {
    :rabbitmq => {
      :enabled => {
        false
       }
     }
   }
 )
```

To enable the rabbitmq repository with a wrapper cookbook, place the following in a recipe:

```ruby
node.default['yum']['rabbitmq']['enabled'] = true
include_recipe 'yum-rabbitmq'
```

## More Examples
Point the base and updates repositories at an internally hosted server.

```ruby
node.default['yum']['rabbitmq']['enabled'] = true
node.default['yum']['rabbitmq']['mirrorlist'] = nil
node.default['yum']['rabbitmq']['baseurl'] = 'https://internal.example.com/rabbitmq/6/os/x86_64'
node.default['yum']['rabbitmq']['sslverify'] = false

include_recipe 'yum-rabbitmq'
```

## Maintainers

* Chase Bolt (<chase.bolt@gmail.com>)

## License
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
